

from ..thirdparty import Enum

DataObjectTypes = Enum(*[
    "AboutInfo",
    "AccountCreatedEvent",
    "AccountRemovedEvent",
    "AccountUpdatedEvent",
    "Action",
    "ActiveDirectoryProfile",
    "AdminPasswordNotChangedEvent",
    "AfterStartupTaskScheduler",
    "AlarmAcknowledgedEvent",
    "AlarmAction",
    "AlarmActionTriggeredEvent",
    "AlarmClearedEvent",
    "AlarmCreatedEvent",
    "AlarmDescription",
    "AlarmEmailCompletedEvent",
    "AlarmEmailFailedEvent",
    "AlarmEvent",
    "AlarmEventArgument",
    "AlarmExpression",
    "AlarmInfo",
    "AlarmReconfiguredEvent",
    "AlarmRemovedEvent",
    "AlarmScriptCompleteEvent",
    "AlarmScriptFailedEvent",
    "AlarmSetting",
    "AlarmSnmpCompletedEvent",
    "AlarmSnmpFailedEvent",
    "AlarmSpec",
    "AlarmState",
    "AlarmStatusChangedEvent",
    "AlarmTriggeringAction",
    "AlarmTriggeringActionTransitionSpec",
    "AllVirtualMachinesLicensedEvent",
    "AlreadyAuthenticatedSessionEvent",
    "AndAlarmExpression",
    "AnswerFile",
    "AnswerFileCreateSpec",
    "AnswerFileOptionsCreateSpec",
    "AnswerFileSerializedCreateSpec",
    "AnswerFileStatusError",
    "AnswerFileStatusResult",
    "AnswerFileUpdateFailure",
    "ApplyProfile",
    "ApplyStorageRecommendationResult",
    "ArrayUpdateSpec",
    "AuthenticationProfile",
    "AuthorizationDescription",
    "AuthorizationEvent",
    "AuthorizationPrivilege",
    "AuthorizationRole",
    "AutoStartDefaults",
    "AutoStartPowerInfo",
    "BadUsernameSessionEvent",
    "BoolOption",
    "BoolPolicy",
    "CanceledHostOperationEvent",
    "Capability",
    "CheckResult",
    "ChoiceOption",
    "ClusterAction",
    "ClusterActionHistory",
    "ClusterAffinityRuleSpec",
    "ClusterAntiAffinityRuleSpec",
    "ClusterAttemptedVmInfo",
    "ClusterComplianceCheckedEvent",
    "ClusterComputeResourceSummary",
    "ClusterConfigInfo",
    "ClusterConfigInfoEx",
    "ClusterConfigSpec",
    "ClusterConfigSpecEx",
    "ClusterCreatedEvent",
    "ClusterDasAamHostInfo",
    "ClusterDasAamNodeState",
    "ClusterDasAdmissionControlInfo",
    "ClusterDasAdmissionControlPolicy",
    "ClusterDasAdvancedRuntimeInfo",
    "ClusterDasConfigInfo",
    "ClusterDasData",
    "ClusterDasDataSummary",
    "ClusterDasFailoverLevelAdvancedRuntimeInfo",
    "ClusterDasFailoverLevelAdvancedRuntimeInfoHostSlots",
    "ClusterDasFailoverLevelAdvancedRuntimeInfoSlotInfo",
    "ClusterDasFdmHostState",
    "ClusterDasHostInfo",
    "ClusterDasHostRecommendation",
    "ClusterDasVmConfigInfo",
    "ClusterDasVmConfigSpec",
    "ClusterDasVmSettings",
    "ClusterDestroyedEvent",
    "ClusterDpmConfigInfo",
    "ClusterDpmHostConfigInfo",
    "ClusterDpmHostConfigSpec",
    "ClusterDrsConfigInfo",
    "ClusterDrsFaults",
    "ClusterDrsFaultsFaultsByVirtualDisk",
    "ClusterDrsFaultsFaultsByVm",
    "ClusterDrsMigration",
    "ClusterDrsRecommendation",
    "ClusterDrsVmConfigInfo",
    "ClusterDrsVmConfigSpec",
    "ClusterEnterMaintenanceResult",
    "ClusterEvent",
    "ClusterFailoverHostAdmissionControlInfo",
    "ClusterFailoverHostAdmissionControlInfoHostStatus",
    "ClusterFailoverHostAdmissionControlPolicy",
    "ClusterFailoverLevelAdmissionControlInfo",
    "ClusterFailoverLevelAdmissionControlPolicy",
    "ClusterFailoverResourcesAdmissionControlInfo",
    "ClusterFailoverResourcesAdmissionControlPolicy",
    "ClusterGroupInfo",
    "ClusterGroupSpec",
    "ClusterHostGroup",
    "ClusterHostPowerAction",
    "ClusterHostRecommendation",
    "ClusterInitialPlacementAction",
    "ClusterMigrationAction",
    "ClusterNotAttemptedVmInfo",
    "ClusterOvercommittedEvent",
    "ClusterPowerOnVmResult",
    "ClusterProfileCompleteConfigSpec",
    "ClusterProfileConfigInfo",
    "ClusterProfileConfigServiceCreateSpec",
    "ClusterProfileConfigSpec",
    "ClusterProfileCreateSpec",
    "ClusterRecommendation",
    "ClusterReconfiguredEvent",
    "ClusterRuleInfo",
    "ClusterRuleSpec",
    "ClusterStatusChangedEvent",
    "ClusterVmGroup",
    "ClusterVmHostRuleInfo",
    "ClusterVmToolsMonitoringSettings",
    "ComplianceFailure",
    "ComplianceLocator",
    "ComplianceProfile",
    "ComplianceResult",
    "CompositePolicyOption",
    "ComputeResourceConfigInfo",
    "ComputeResourceConfigSpec",
    "ComputeResourceEventArgument",
    "ComputeResourceHostSPBMLicenseInfo",
    "ComputeResourceSummary",
    "ConfigTarget",
    "CreateTaskAction",
    "CustomFieldDef",
    "CustomFieldDefAddedEvent",
    "CustomFieldDefEvent",
    "CustomFieldDefRemovedEvent",
    "CustomFieldDefRenamedEvent",
    "CustomFieldEvent",
    "CustomFieldStringValue",
    "CustomFieldValue",
    "CustomFieldValueChangedEvent",
    "CustomizationAdapterMapping",
    "CustomizationAutoIpV6Generator",
    "CustomizationCustomIpGenerator",
    "CustomizationCustomIpV6Generator",
    "CustomizationCustomName",
    "CustomizationDhcpIpGenerator",
    "CustomizationDhcpIpV6Generator",
    "CustomizationEvent",
    "CustomizationFailed",
    "CustomizationFixedIp",
    "CustomizationFixedIpV6",
    "CustomizationFixedName",
    "CustomizationGlobalIPSettings",
    "CustomizationGuiRunOnce",
    "CustomizationGuiUnattended",
    "CustomizationIPSettings",
    "CustomizationIPSettingsIpV6AddressSpec",
    "CustomizationIdentification",
    "CustomizationIdentitySettings",
    "CustomizationIpGenerator",
    "CustomizationIpV6Generator",
    "CustomizationLicenseFilePrintData",
    "CustomizationLinuxIdentityFailed",
    "CustomizationLinuxOptions",
    "CustomizationLinuxPrep",
    "CustomizationName",
    "CustomizationNetworkSetupFailed",
    "CustomizationOptions",
    "CustomizationPassword",
    "CustomizationPrefixName",
    "CustomizationSpec",
    "CustomizationSpecInfo",
    "CustomizationSpecItem",
    "CustomizationStartedEvent",
    "CustomizationStatelessIpV6Generator",
    "CustomizationSucceeded",
    "CustomizationSysprep",
    "CustomizationSysprepFailed",
    "CustomizationSysprepText",
    "CustomizationUnknownFailure",
    "CustomizationUnknownIpGenerator",
    "CustomizationUnknownIpV6Generator",
    "CustomizationUnknownName",
    "CustomizationUserData",
    "CustomizationVirtualMachineName",
    "CustomizationWinOptions",
    "DVPortConfigInfo",
    "DVPortConfigSpec",
    "DVPortSetting",
    "DVPortState",
    "DVPortStatus",
    "DVPortgroupConfigInfo",
    "DVPortgroupConfigSpec",
    "DVPortgroupCreatedEvent",
    "DVPortgroupDestroyedEvent",
    "DVPortgroupEvent",
    "DVPortgroupPolicy",
    "DVPortgroupReconfiguredEvent",
    "DVPortgroupRenamedEvent",
    "DVSCapability",
    "DVSConfigInfo",
    "DVSConfigSpec",
    "DVSContactInfo",
    "DVSCreateSpec",
    "DVSFailureCriteria",
    "DVSFeatureCapability",
    "DVSManagerDvsConfigTarget",
    "DVSNameArrayUplinkPortPolicy",
    "DVSNetworkResourceManagementCapability",
    "DVSNetworkResourcePool",
    "DVSNetworkResourcePoolAllocationInfo",
    "DVSNetworkResourcePoolConfigSpec",
    "DVSPolicy",
    "DVSSecurityPolicy",
    "DVSSummary",
    "DVSTrafficShapingPolicy",
    "DVSUplinkPortPolicy",
    "DVSVendorSpecificConfig",
    "DailyTaskScheduler",
    "DasAdmissionControlDisabledEvent",
    "DasAdmissionControlEnabledEvent",
    "DasAgentFoundEvent",
    "DasAgentUnavailableEvent",
    "DasClusterIsolatedEvent",
    "DasDisabledEvent",
    "DasEnabledEvent",
    "DasHeartbeatDatastoreInfo",
    "DasHostFailedEvent",
    "DasHostIsolatedEvent",
    "DatabaseSizeEstimate",
    "DatabaseSizeParam",
    "DatacenterCreatedEvent",
    "DatacenterEvent",
    "DatacenterEventArgument",
    "DatacenterMismatchArgument",
    "DatacenterRenamedEvent",
    "DatastoreCapability",
    "DatastoreCapacityIncreasedEvent",
    "DatastoreDestroyedEvent",
    "DatastoreDiscoveredEvent",
    "DatastoreDuplicatedEvent",
    "DatastoreEvent",
    "DatastoreEventArgument",
    "DatastoreFileCopiedEvent",
    "DatastoreFileDeletedEvent",
    "DatastoreFileEvent",
    "DatastoreFileMovedEvent",
    "DatastoreHostMount",
    "DatastoreIORMReconfiguredEvent",
    "DatastoreInfo",
    "DatastoreMountPathDatastorePair",
    "DatastoreOption",
    "DatastorePrincipalConfigured",
    "DatastoreRemovedOnHostEvent",
    "DatastoreRenamedEvent",
    "DatastoreRenamedOnHostEvent",
    "DatastoreSummary",
    "DateTimeProfile",
    "Description",
    "DeviceBackedVirtualDiskSpec",
    "DiagnosticManagerBundleInfo",
    "DiagnosticManagerLogDescriptor",
    "DiagnosticManagerLogHeader",
    "DiskChangeExtent",
    "DiskChangeInfo",
    "DistributedVirtualPort",
    "DistributedVirtualPortgroupInfo",
    "DistributedVirtualSwitchHostMember",
    "DistributedVirtualSwitchHostMemberBacking",
    "DistributedVirtualSwitchHostMemberConfigInfo",
    "DistributedVirtualSwitchHostMemberConfigSpec",
    "DistributedVirtualSwitchHostMemberPnicBacking",
    "DistributedVirtualSwitchHostMemberPnicSpec",
    "DistributedVirtualSwitchHostMemberRuntimeState",
    "DistributedVirtualSwitchHostProductSpec",
    "DistributedVirtualSwitchInfo",
    "DistributedVirtualSwitchKeyedOpaqueBlob",
    "DistributedVirtualSwitchManagerCompatibilityResult",
    "DistributedVirtualSwitchManagerDvsProductSpec",
    "DistributedVirtualSwitchManagerHostArrayFilter",
    "DistributedVirtualSwitchManagerHostContainer",
    "DistributedVirtualSwitchManagerHostContainerFilter",
    "DistributedVirtualSwitchManagerHostDvsFilterSpec",
    "DistributedVirtualSwitchManagerHostDvsMembershipFilter",
    "DistributedVirtualSwitchPortConnectee",
    "DistributedVirtualSwitchPortConnection",
    "DistributedVirtualSwitchPortCriteria",
    "DistributedVirtualSwitchPortStatistics",
    "DistributedVirtualSwitchProductSpec",
    "DrsDisabledEvent",
    "DrsEnabledEvent",
    "DrsEnteredStandbyModeEvent",
    "DrsEnteringStandbyModeEvent",
    "DrsExitStandbyModeFailedEvent",
    "DrsExitedStandbyModeEvent",
    "DrsExitingStandbyModeEvent",
    "DrsInvocationFailedEvent",
    "DrsRecoveredFromFailureEvent",
    "DrsResourceConfigureFailedEvent",
    "DrsResourceConfigureSyncedEvent",
    "DrsRuleComplianceEvent",
    "DrsRuleViolationEvent",
    "DrsVmMigratedEvent",
    "DrsVmPoweredOnEvent",
    "DuplicateIpDetectedEvent",
    "DvsCreatedEvent",
    "DvsDestroyedEvent",
    "DvsEvent",
    "DvsEventArgument",
    "DvsHostBackInSyncEvent",
    "DvsHostJoinedEvent",
    "DvsHostLeftEvent",
    "DvsHostStatusUpdated",
    "DvsHostVNicProfile",
    "DvsHostWentOutOfSyncEvent",
    "DvsMergedEvent",
    "DvsOperationBulkFaultFaultOnHost",
    "DvsOutOfSyncHostArgument",
    "DvsPortBlockedEvent",
    "DvsPortConnectedEvent",
    "DvsPortCreatedEvent",
    "DvsPortDeletedEvent",
    "DvsPortDisconnectedEvent",
    "DvsPortEnteredPassthruEvent",
    "DvsPortExitedPassthruEvent",
    "DvsPortJoinPortgroupEvent",
    "DvsPortLeavePortgroupEvent",
    "DvsPortLinkDownEvent",
    "DvsPortLinkUpEvent",
    "DvsPortReconfiguredEvent",
    "DvsPortUnblockedEvent",
    "DvsProfile",
    "DvsReconfiguredEvent",
    "DvsRenamedEvent",
    "DvsServiceConsoleVNicProfile",
    "DvsUpgradeAvailableEvent",
    "DvsUpgradeInProgressEvent",
    "DvsUpgradeRejectedEvent",
    "DvsUpgradedEvent",
    "DvsVNicProfile",
    "DynamicArray",
    "DynamicData",
    "DynamicProperty",
    "DynamicTypeEnumTypeInfo",
    "DynamicTypeMgrAllTypeInfo",
    "DynamicTypeMgrAnnotation",
    "DynamicTypeMgrDataTypeInfo",
    "DynamicTypeMgrManagedTypeInfo",
    "DynamicTypeMgrMethodTypeInfo",
    "DynamicTypeMgrMoFilterSpec",
    "DynamicTypeMgrMoInstance",
    "DynamicTypeMgrParamTypeInfo",
    "DynamicTypeMgrPropertyTypeInfo",
    "DynamicTypeMgrTypeFilterSpec",
    "EVCMode",
    "ElementDescription",
    "EnteredMaintenanceModeEvent",
    "EnteredStandbyModeEvent",
    "EnteringMaintenanceModeEvent",
    "EnteringStandbyModeEvent",
    "EntityEventArgument",
    "EnumDescription",
    "ErrorUpgradeEvent",
    "EvaluationLicenseSource",
    "Event",
    "EventAlarmExpression",
    "EventAlarmExpressionComparison",
    "EventArgDesc",
    "EventArgument",
    "EventDescription",
    "EventDescriptionEventDetail",
    "EventEx",
    "EventFilterSpec",
    "EventFilterSpecByEntity",
    "EventFilterSpecByTime",
    "EventFilterSpecByUsername",
    "ExitMaintenanceModeEvent",
    "ExitStandbyModeFailedEvent",
    "ExitedStandbyModeEvent",
    "ExitingStandbyModeEvent",
    "ExtExtendedProductInfo",
    "ExtManagedEntityInfo",
    "ExtSolutionManagerInfo",
    "ExtSolutionManagerInfoTabInfo",
    "ExtendedDescription",
    "ExtendedElementDescription",
    "ExtendedEvent",
    "ExtendedEventPair",
    "Extension",
    "ExtensionClientInfo",
    "ExtensionEventTypeInfo",
    "ExtensionFaultTypeInfo",
    "ExtensionHealthInfo",
    "ExtensionOvfConsumerInfo",
    "ExtensionPrivilegeInfo",
    "ExtensionResourceInfo",
    "ExtensionServerInfo",
    "ExtensionTaskTypeInfo",
    "FailoverLevelRestored",
    "FaultToleranceConfigInfo",
    "FaultTolerancePrimaryConfigInfo",
    "FaultToleranceSecondaryConfigInfo",
    "FaultToleranceSecondaryOpResult",
    "FcoeConfig",
    "FcoeConfigFcoeCapabilities",
    "FcoeConfigFcoeSpecification",
    "FcoeConfigVlanRange",
    "FileBackedVirtualDiskSpec",
    "FileInfo",
    "FileQuery",
    "FileQueryFlags",
    "FileTransferInformation",
    "FirewallProfile",
    "FirewallProfileRulesetProfile",
    "FloatOption",
    "FloppyImageFileInfo",
    "FloppyImageFileQuery",
    "FolderEventArgument",
    "FolderFileInfo",
    "FolderFileQuery",
    "GeneralEvent",
    "GeneralHostErrorEvent",
    "GeneralHostInfoEvent",
    "GeneralHostWarningEvent",
    "GeneralUserEvent",
    "GeneralVmErrorEvent",
    "GeneralVmInfoEvent",
    "GeneralVmWarningEvent",
    "GhostDvsProxySwitchDetectedEvent",
    "GhostDvsProxySwitchRemovedEvent",
    "GlobalMessageChangedEvent",
    "GroupAlarmAction",
    "GuestAuthentication",
    "GuestDiskInfo",
    "GuestFileAttributes",
    "GuestFileInfo",
    "GuestInfo",
    "GuestListFileInfo",
    "GuestNicInfo",
    "GuestOsDescriptor",
    "GuestPosixFileAttributes",
    "GuestProcessInfo",
    "GuestProgramSpec",
    "GuestScreenInfo",
    "GuestStackInfo",
    "GuestWindowsFileAttributes",
    "GuestWindowsProgramSpec",
    "HbrManagerReplicationVmInfo",
    "HealthStatusChangedEvent",
    "HealthSystemRuntime",
    "HostAccountSpec",
    "HostActiveDirectory",
    "HostActiveDirectoryInfo",
    "HostActiveDirectorySpec",
    "HostAddFailedEvent",
    "HostAddedEvent",
    "HostAdminDisableEvent",
    "HostAdminEnableEvent",
    "HostApplyProfile",
    "HostAuthenticationManagerInfo",
    "HostAuthenticationStoreInfo",
    "HostAutoStartManagerConfig",
    "HostBIOSInfo",
    "HostBlockAdapterTargetTransport",
    "HostBlockHba",
    "HostBootDevice",
    "HostBootDeviceInfo",
    "HostCacheConfigurationInfo",
    "HostCacheConfigurationSpec",
    "HostCapability",
    "HostCnxFailedAccountFailedEvent",
    "HostCnxFailedAlreadyManagedEvent",
    "HostCnxFailedBadCcagentEvent",
    "HostCnxFailedBadUsernameEvent",
    "HostCnxFailedBadVersionEvent",
    "HostCnxFailedCcagentUpgradeEvent",
    "HostCnxFailedEvent",
    "HostCnxFailedNetworkErrorEvent",
    "HostCnxFailedNoAccessEvent",
    "HostCnxFailedNoConnectionEvent",
    "HostCnxFailedNoLicenseEvent",
    "HostCnxFailedNotFoundEvent",
    "HostCnxFailedTimeoutEvent",
    "HostComplianceCheckedEvent",
    "HostCompliantEvent",
    "HostConfigAppliedEvent",
    "HostConfigChange",
    "HostConfigInfo",
    "HostConfigManager",
    "HostConfigSpec",
    "HostConfigSummary",
    "HostConnectInfo",
    "HostConnectInfoNetworkInfo",
    "HostConnectSpec",
    "HostConnectedEvent",
    "HostConnectionLostEvent",
    "HostCpuIdInfo",
    "HostCpuInfo",
    "HostCpuPackage",
    "HostCpuPowerManagementInfo",
    "HostDasDisabledEvent",
    "HostDasDisablingEvent",
    "HostDasEnabledEvent",
    "HostDasEnablingEvent",
    "HostDasErrorEvent",
    "HostDasEvent",
    "HostDasOkEvent",
    "HostDatastoreBrowserSearchResults",
    "HostDatastoreBrowserSearchSpec",
    "HostDatastoreConnectInfo",
    "HostDatastoreExistsConnectInfo",
    "HostDatastoreNameConflictConnectInfo",
    "HostDatastoreSystemCapabilities",
    "HostDateTimeConfig",
    "HostDateTimeInfo",
    "HostDateTimeSystemTimeZone",
    "HostDevice",
    "HostDhcpService",
    "HostDhcpServiceConfig",
    "HostDhcpServiceSpec",
    "HostDiagnosticPartition",
    "HostDiagnosticPartitionCreateDescription",
    "HostDiagnosticPartitionCreateOption",
    "HostDiagnosticPartitionCreateSpec",
    "HostDigestInfo",
    "HostDirectoryStoreInfo",
    "HostDisconnectedEvent",
    "HostDiskDimensions",
    "HostDiskDimensionsChs",
    "HostDiskDimensionsLba",
    "HostDiskMappingInfo",
    "HostDiskMappingOption",
    "HostDiskMappingPartitionInfo",
    "HostDiskMappingPartitionOption",
    "HostDiskPartitionAttributes",
    "HostDiskPartitionBlockRange",
    "HostDiskPartitionInfo",
    "HostDiskPartitionLayout",
    "HostDiskPartitionSpec",
    "HostDnsConfig",
    "HostDnsConfigSpec",
    "HostEnableAdminFailedEvent",
    "HostEsxAgentHostManagerConfigInfo",
    "HostEvent",
    "HostEventArgument",
    "HostExtraNetworksEvent",
    "HostFeatureVersionInfo",
    "HostFibreChannelHba",
    "HostFibreChannelOverEthernetHba",
    "HostFibreChannelOverEthernetHbaLinkInfo",
    "HostFibreChannelOverEthernetTargetTransport",
    "HostFibreChannelTargetTransport",
    "HostFileAccess",
    "HostFileSystemMountInfo",
    "HostFileSystemVolume",
    "HostFileSystemVolumeInfo",
    "HostFirewallConfig",
    "HostFirewallConfigRuleSetConfig",
    "HostFirewallDefaultPolicy",
    "HostFirewallInfo",
    "HostFirewallRule",
    "HostFirewallRuleset",
    "HostFirewallRulesetIpList",
    "HostFirewallRulesetIpNetwork",
    "HostFirewallRulesetRulesetSpec",
    "HostFlagInfo",
    "HostForceMountedInfo",
    "HostGetShortNameFailedEvent",
    "HostHardwareElementInfo",
    "HostHardwareInfo",
    "HostHardwareStatusInfo",
    "HostHardwareSummary",
    "HostHostBusAdapter",
    "HostHyperThreadScheduleInfo",
    "HostImageProfileSummary",
    "HostInAuditModeEvent",
    "HostInternetScsiHba",
    "HostInternetScsiHbaAuthenticationCapabilities",
    "HostInternetScsiHbaAuthenticationProperties",
    "HostInternetScsiHbaDigestCapabilities",
    "HostInternetScsiHbaDigestProperties",
    "HostInternetScsiHbaDiscoveryCapabilities",
    "HostInternetScsiHbaDiscoveryProperties",
    "HostInternetScsiHbaIPCapabilities",
    "HostInternetScsiHbaIPProperties",
    "HostInternetScsiHbaParamValue",
    "HostInternetScsiHbaSendTarget",
    "HostInternetScsiHbaStaticTarget",
    "HostInternetScsiHbaTargetSet",
    "HostInternetScsiTargetTransport",
    "HostInventoryFullEvent",
    "HostInventoryUnreadableEvent",
    "HostIpChangedEvent",
    "HostIpConfig",
    "HostIpConfigIpV6Address",
    "HostIpConfigIpV6AddressConfiguration",
    "HostIpInconsistentEvent",
    "HostIpRouteConfig",
    "HostIpRouteConfigSpec",
    "HostIpRouteEntry",
    "HostIpRouteOp",
    "HostIpRouteTableConfig",
    "HostIpRouteTableInfo",
    "HostIpToShortNameFailedEvent",
    "HostIpmiInfo",
    "HostIsolationIpPingFailedEvent",
    "HostLicensableResourceInfo",
    "HostLicenseConnectInfo",
    "HostLicenseExpiredEvent",
    "HostLicenseSpec",
    "HostListSummary",
    "HostListSummaryQuickStats",
    "HostLocalAuthenticationInfo",
    "HostLocalFileSystemVolume",
    "HostLocalFileSystemVolumeSpec",
    "HostLowLevelProvisioningManagerDiskLayoutSpec",
    "HostLowLevelProvisioningManagerSnapshotLayoutSpec",
    "HostMemoryProfile",
    "HostMemorySpec",
    "HostMissingNetworksEvent",
    "HostMonitoringStateChangedEvent",
    "HostMountInfo",
    "HostMultipathInfo",
    "HostMultipathInfoFixedLogicalUnitPolicy",
    "HostMultipathInfoLogicalUnit",
    "HostMultipathInfoLogicalUnitPolicy",
    "HostMultipathInfoLogicalUnitStorageArrayTypePolicy",
    "HostMultipathInfoPath",
    "HostMultipathStateInfo",
    "HostMultipathStateInfoPath",
    "HostNasVolume",
    "HostNasVolumeConfig",
    "HostNasVolumeSpec",
    "HostNatService",
    "HostNatServiceConfig",
    "HostNatServiceNameServiceSpec",
    "HostNatServicePortForwardSpec",
    "HostNatServiceSpec",
    "HostNetCapabilities",
    "HostNetOffloadCapabilities",
    "HostNetworkConfig",
    "HostNetworkConfigResult",
    "HostNetworkInfo",
    "HostNetworkPolicy",
    "HostNetworkSecurityPolicy",
    "HostNetworkTrafficShapingPolicy",
    "HostNewNetworkConnectInfo",
    "HostNicFailureCriteria",
    "HostNicOrderPolicy",
    "HostNicTeamingPolicy",
    "HostNoAvailableNetworksEvent",
    "HostNoHAEnabledPortGroupsEvent",
    "HostNoRedundantManagementNetworkEvent",
    "HostNonCompliantEvent",
    "HostNotInClusterEvent",
    "HostNtpConfig",
    "HostNumaInfo",
    "HostNumaNode",
    "HostNumericSensorInfo",
    "HostOvercommittedEvent",
    "HostParallelScsiHba",
    "HostParallelScsiTargetTransport",
    "HostPatchManagerLocator",
    "HostPatchManagerPatchManagerOperationSpec",
    "HostPatchManagerResult",
    "HostPatchManagerStatus",
    "HostPatchManagerStatusPrerequisitePatch",
    "HostPathSelectionPolicyOption",
    "HostPciDevice",
    "HostPciPassthruConfig",
    "HostPciPassthruInfo",
    "HostPlugStoreTopology",
    "HostPlugStoreTopologyAdapter",
    "HostPlugStoreTopologyDevice",
    "HostPlugStoreTopologyPath",
    "HostPlugStoreTopologyPlugin",
    "HostPlugStoreTopologyTarget",
    "HostPortGroup",
    "HostPortGroupConfig",
    "HostPortGroupPort",
    "HostPortGroupProfile",
    "HostPortGroupSpec",
    "HostPosixAccountSpec",
    "HostPowerPolicy",
    "HostPrimaryAgentNotShortNameEvent",
    "HostProfileAppliedEvent",
    "HostProfileCompleteConfigSpec",
    "HostProfileConfigInfo",
    "HostProfileConfigSpec",
    "HostProfileHostBasedConfigSpec",
    "HostProfileManagerConfigTaskList",
    "HostProfileSerializedHostProfileSpec",
    "HostProxySwitch",
    "HostProxySwitchConfig",
    "HostProxySwitchSpec",
    "HostReconnectionFailedEvent",
    "HostRemovedEvent",
    "HostResignatureRescanResult",
    "HostRuntimeInfo",
    "HostScsiDisk",
    "HostScsiDiskPartition",
    "HostScsiTopology",
    "HostScsiTopologyInterface",
    "HostScsiTopologyLun",
    "HostScsiTopologyTarget",
    "HostSecuritySpec",
    "HostService",
    "HostServiceConfig",
    "HostServiceInfo",
    "HostServiceSourcePackage",
    "HostServiceTicket",
    "HostShortNameInconsistentEvent",
    "HostShortNameToIpFailedEvent",
    "HostShutdownEvent",
    "HostSnmpConfigSpec",
    "HostSnmpDestination",
    "HostSnmpSystemAgentLimits",
    "HostSslThumbprintInfo",
    "HostStatusChangedEvent",
    "HostStorageArrayTypePolicyOption",
    "HostStorageDeviceInfo",
    "HostStorageElementInfo",
    "HostStorageOperationalInfo",
    "HostSyncFailedEvent",
    "HostSystemHealthInfo",
    "HostSystemIdentificationInfo",
    "HostSystemInfo",
    "HostSystemReconnectSpec",
    "HostSystemResourceInfo",
    "HostTargetTransport",
    "HostTpmDigestInfo",
    "HostUnresolvedVmfsExtent",
    "HostUnresolvedVmfsResignatureSpec",
    "HostUnresolvedVmfsResolutionResult",
    "HostUnresolvedVmfsResolutionSpec",
    "HostUnresolvedVmfsVolume",
    "HostUnresolvedVmfsVolumeResolveStatus",
    "HostUpgradeFailedEvent",
    "HostUserWorldSwapNotEnabledEvent",
    "HostVMotionCompatibility",
    "HostVMotionConfig",
    "HostVMotionInfo",
    "HostVMotionNetConfig",
    "HostVfatVolume",
    "HostVirtualNic",
    "HostVirtualNicConfig",
    "HostVirtualNicConnection",
    "HostVirtualNicManagerInfo",
    "HostVirtualNicManagerNicTypeSelection",
    "HostVirtualNicSpec",
    "HostVirtualSwitch",
    "HostVirtualSwitchAutoBridge",
    "HostVirtualSwitchBeaconConfig",
    "HostVirtualSwitchBondBridge",
    "HostVirtualSwitchBridge",
    "HostVirtualSwitchConfig",
    "HostVirtualSwitchSimpleBridge",
    "HostVirtualSwitchSpec",
    "HostVmciAccessManagerAccessSpec",
    "HostVmfsRescanResult",
    "HostVmfsSpec",
    "HostVmfsVolume",
    "HostVnicConnectedToCustomizedDVPortEvent",
    "HostWwnChangedEvent",
    "HostWwnConflictEvent",
    "HourlyTaskScheduler",
    "HttpNfcLeaseDatastoreLeaseInfo",
    "HttpNfcLeaseDeviceUrl",
    "HttpNfcLeaseHostInfo",
    "HttpNfcLeaseInfo",
    "HttpNfcLeaseManifestEntry",
    "IScsiBootFailureEvent",
    "ImportSpec",
    "IncorrectHostInformationEvent",
    "InfoUpgradeEvent",
    "InheritablePolicy",
    "InsufficientFailoverResourcesEvent",
    "IntOption",
    "IntPolicy",
    "InvalidEditionEvent",
    "InventoryDescription",
    "IpAddressProfile",
    "IpPool",
    "IpPoolAssociation",
    "IpPoolIpPoolConfigInfo",
    "IpRouteProfile",
    "IscsiDependencyEntity",
    "IscsiMigrationDependency",
    "IscsiPortInfo",
    "IscsiStatus",
    "IsoImageFileInfo",
    "IsoImageFileQuery",
    "KernelModuleInfo",
    "KernelModuleSectionInfo",
    "KeyAnyValue",
    "KeyValue",
    "LicenseAssignmentManagerLicenseAssignment",
    "LicenseAvailabilityInfo",
    "LicenseDiagnostics",
    "LicenseEvent",
    "LicenseExpiredEvent",
    "LicenseFeatureInfo",
    "LicenseManagerEvaluationInfo",
    "LicenseManagerLicenseInfo",
    "LicenseNonComplianceEvent",
    "LicenseReservationInfo",
    "LicenseRestrictedEvent",
    "LicenseServerAvailableEvent",
    "LicenseServerSource",
    "LicenseServerUnavailableEvent",
    "LicenseSource",
    "LicenseUsageInfo",
    "LinkDiscoveryProtocolConfig",
    "LinkLayerDiscoveryProtocolInfo",
    "LinkProfile",
    "LocalDatastoreCreatedEvent",
    "LocalDatastoreInfo",
    "LocalLicenseSource",
    "LocalTSMEnabledEvent",
    "LocalizableMessage",
    "LocalizationManagerMessageCatalog",
    "LocalizedMethodFault",
    "LockerMisconfiguredEvent",
    "LockerReconfiguredEvent",
    "LongOption",
    "LongPolicy",
    "ManagedByInfo",
    "ManagedEntityEventArgument",
    "ManagedObjectReference",
    "MethodAction",
    "MethodActionArgument",
    "MethodDescription",
    "MetricAlarmExpression",
    "MigrationErrorEvent",
    "MigrationEvent",
    "MigrationHostErrorEvent",
    "MigrationHostWarningEvent",
    "MigrationResourceErrorEvent",
    "MigrationResourceWarningEvent",
    "MigrationWarningEvent",
    "MissingObject",
    "MissingProperty",
    "ModeInfo",
    "MonthlyByDayTaskScheduler",
    "MonthlyByWeekdayTaskScheduler",
    "MonthlyTaskScheduler",
    "MultipleCertificatesVerifyFaultThumbprintData",
    "NASDatastoreCreatedEvent",
    "NamePasswordAuthentication",
    "NasDatastoreInfo",
    "NasStorageProfile",
    "NetBIOSConfigInfo",
    "NetDhcpConfigInfo",
    "NetDhcpConfigInfoDhcpOptions",
    "NetDhcpConfigSpec",
    "NetDhcpConfigSpecDhcpOptionsSpec",
    "NetDnsConfigInfo",
    "NetDnsConfigSpec",
    "NetIpConfigInfo",
    "NetIpConfigInfoIpAddress",
    "NetIpConfigSpec",
    "NetIpConfigSpecIpAddressSpec",
    "NetIpRouteConfigInfo",
    "NetIpRouteConfigInfoGateway",
    "NetIpRouteConfigInfoIpRoute",
    "NetIpRouteConfigSpec",
    "NetIpRouteConfigSpecGatewaySpec",
    "NetIpRouteConfigSpecIpRouteSpec",
    "NetIpStackInfo",
    "NetIpStackInfoDefaultRouter",
    "NetIpStackInfoNetToMedia",
    "NetworkEventArgument",
    "NetworkPolicyProfile",
    "NetworkProfile",
    "NetworkProfileDnsConfigProfile",
    "NetworkSummary",
    "NoAccessUserEvent",
    "NoDatastoresConfiguredEvent",
    "NoLicenseEvent",
    "NoMaintenanceModeDrsRecommendationForVM",
    "NonVIWorkloadDetectedOnDatastoreEvent",
    "NotEnoughResourcesToStartVmEvent",
    "NumPortsProfile",
    "NumericRange",
    "ObjectContent",
    "ObjectSpec",
    "ObjectUpdate",
    "OnceTaskScheduler",
    "OptionDef",
    "OptionProfile",
    "OptionType",
    "OptionValue",
    "OrAlarmExpression",
    "OutOfSyncDvsHost",
    "OvfConsumerOstNode",
    "OvfConsumerOvfSection",
    "OvfCreateDescriptorParams",
    "OvfCreateDescriptorResult",
    "OvfCreateImportSpecParams",
    "OvfCreateImportSpecResult",
    "OvfDeploymentOption",
    "OvfFile",
    "OvfFileItem",
    "OvfManagerCommonParams",
    "OvfNetworkInfo",
    "OvfNetworkMapping",
    "OvfParseDescriptorParams",
    "OvfParseDescriptorResult",
    "OvfResourceMap",
    "OvfValidateHostParams",
    "OvfValidateHostResult",
    "ParaVirtualSCSIController",
    "ParaVirtualSCSIControllerOption",
    "PasswordField",
    "PerfCompositeMetric",
    "PerfCounterInfo",
    "PerfEntityMetric",
    "PerfEntityMetricBase",
    "PerfEntityMetricCSV",
    "PerfInterval",
    "PerfMetricId",
    "PerfMetricIntSeries",
    "PerfMetricSeries",
    "PerfMetricSeriesCSV",
    "PerfProviderSummary",
    "PerfQuerySpec",
    "PerfSampleInfo",
    "PerformanceDescription",
    "PerformanceManagerCounterLevelMapping",
    "PerformanceStatisticsDescription",
    "Permission",
    "PermissionAddedEvent",
    "PermissionEvent",
    "PermissionProfile",
    "PermissionRemovedEvent",
    "PermissionUpdatedEvent",
    "PhysicalNic",
    "PhysicalNicCdpDeviceCapability",
    "PhysicalNicCdpInfo",
    "PhysicalNicConfig",
    "PhysicalNicHint",
    "PhysicalNicHintInfo",
    "PhysicalNicIpHint",
    "PhysicalNicLinkInfo",
    "PhysicalNicNameHint",
    "PhysicalNicProfile",
    "PhysicalNicSpec",
    "PnicUplinkProfile",
    "PodDiskLocator",
    "PodStorageDrsEntry",
    "PolicyOption",
    "PortGroupProfile",
    "PosixUserSearchResult",
    "PowerSystemCapability",
    "PowerSystemInfo",
    "PrivilegePolicyDef",
    "ProductComponentInfo",
    "ProfileApplyProfileElement",
    "ProfileApplyProfileProperty",
    "ProfileAssociatedEvent",
    "ProfileChangedEvent",
    "ProfileCompositeExpression",
    "ProfileCompositePolicyOptionMetadata",
    "ProfileConfigInfo",
    "ProfileCreateSpec",
    "ProfileCreatedEvent",
    "ProfileDeferredPolicyOptionParameter",
    "ProfileDescription",
    "ProfileDescriptionSection",
    "ProfileDissociatedEvent",
    "ProfileEvent",
    "ProfileEventArgument",
    "ProfileExecuteError",
    "ProfileExecuteResult",
    "ProfileExpression",
    "ProfileExpressionMetadata",
    "ProfileMetadata",
    "ProfileMetadataProfileSortSpec",
    "ProfileParameterMetadata",
    "ProfilePolicy",
    "ProfilePolicyMetadata",
    "ProfilePolicyOptionMetadata",
    "ProfileProfileStructure",
    "ProfileProfileStructureProperty",
    "ProfilePropertyPath",
    "ProfileReferenceHostChangedEvent",
    "ProfileRemovedEvent",
    "ProfileSerializedCreateSpec",
    "ProfileSimpleExpression",
    "ProfileUpdateFailedUpdateFailure",
    "PropertyChange",
    "PropertyFilterSpec",
    "PropertyFilterUpdate",
    "PropertySpec",
    "RecurrentTaskScheduler",
    "ReflectManagedMethodExecuterSoapArgument",
    "ReflectManagedMethodExecuterSoapFault",
    "ReflectManagedMethodExecuterSoapResult",
    "RemoteTSMEnabledEvent",
    "ReplicationInfoDiskSettings",
    "ReplicationVmProgressInfo",
    "ResourceAllocationInfo",
    "ResourceAllocationOption",
    "ResourceConfigOption",
    "ResourceConfigSpec",
    "ResourcePoolCreatedEvent",
    "ResourcePoolDestroyedEvent",
    "ResourcePoolEvent",
    "ResourcePoolEventArgument",
    "ResourcePoolMovedEvent",
    "ResourcePoolQuickStats",
    "ResourcePoolReconfiguredEvent",
    "ResourcePoolResourceUsage",
    "ResourcePoolRuntimeInfo",
    "ResourcePoolSummary",
    "ResourceViolatedEvent",
    "RetrieveOptions",
    "RetrieveResult",
    "RoleAddedEvent",
    "RoleEvent",
    "RoleEventArgument",
    "RoleRemovedEvent",
    "RoleUpdatedEvent",
    "RunScriptAction",
    "SSPIAuthentication",
    "ScheduledTaskCompletedEvent",
    "ScheduledTaskCreatedEvent",
    "ScheduledTaskDescription",
    "ScheduledTaskDetail",
    "ScheduledTaskEmailCompletedEvent",
    "ScheduledTaskEmailFailedEvent",
    "ScheduledTaskEvent",
    "ScheduledTaskEventArgument",
    "ScheduledTaskFailedEvent",
    "ScheduledTaskInfo",
    "ScheduledTaskReconfiguredEvent",
    "ScheduledTaskRemovedEvent",
    "ScheduledTaskSpec",
    "ScheduledTaskStartedEvent",
    "ScsiLun",
    "ScsiLunCapabilities",
    "ScsiLunDescriptor",
    "ScsiLunDurableName",
    "SecurityProfile",
    "SelectionSpec",
    "SendEmailAction",
    "SendSNMPAction",
    "ServerLicenseExpiredEvent",
    "ServerStartedSessionEvent",
    "ServiceConsolePortGroupProfile",
    "ServiceConsoleReservationInfo",
    "ServiceContent",
    "ServiceProfile",
    "SessionEvent",
    "SessionManagerGenericServiceTicket",
    "SessionManagerHttpServiceRequestSpec",
    "SessionManagerLocalTicket",
    "SessionManagerServiceRequestSpec",
    "SessionTerminatedEvent",
    "SharesInfo",
    "SharesOption",
    "StateAlarmExpression",
    "StaticRouteProfile",
    "StorageDrsConfigInfo",
    "StorageDrsConfigSpec",
    "StorageDrsIoLoadBalanceConfig",
    "StorageDrsOptionSpec",
    "StorageDrsPodConfigInfo",
    "StorageDrsPodConfigSpec",
    "StorageDrsPodSelectionSpec",
    "StorageDrsSpaceLoadBalanceConfig",
    "StorageDrsVmConfigInfo",
    "StorageDrsVmConfigSpec",
    "StorageIOAllocationInfo",
    "StorageIOAllocationOption",
    "StorageIORMConfigOption",
    "StorageIORMConfigSpec",
    "StorageIORMInfo",
    "StorageMigrationAction",
    "StoragePlacementAction",
    "StoragePlacementResult",
    "StoragePlacementSpec",
    "StoragePodSummary",
    "StorageProfile",
    "StorageRequirement",
    "StringOption",
    "StringPolicy",
    "Tag",
    "TaskDescription",
    "TaskEvent",
    "TaskFilterSpec",
    "TaskFilterSpecByEntity",
    "TaskFilterSpecByTime",
    "TaskFilterSpecByUsername",
    "TaskInfo",
    "TaskReason",
    "TaskReasonAlarm",
    "TaskReasonSchedule",
    "TaskReasonSystem",
    "TaskReasonUser",
    "TaskScheduler",
    "TaskTimeoutEvent",
    "TemplateBeingUpgradedEvent",
    "TemplateConfigFileInfo",
    "TemplateConfigFileQuery",
    "TemplateUpgradeEvent",
    "TemplateUpgradeFailedEvent",
    "TemplateUpgradedEvent",
    "TicketedSessionAuthentication",
    "TimedOutHostOperationEvent",
    "ToolsConfigInfo",
    "ToolsConfigInfoToolsLastInstallInfo",
    "TraversalSpec",
    "TypeDescription",
    "UnlicensedVirtualMachinesEvent",
    "UnlicensedVirtualMachinesFoundEvent",
    "UpdateSet",
    "UpdateVirtualMachineFilesResult",
    "UpdateVirtualMachineFilesResultFailedVmFileInfo",
    "UpdatedAgentBeingRestartedEvent",
    "UpgradeEvent",
    "UserAssignedToGroup",
    "UserGroupProfile",
    "UserInputRequiredParameterMetadata",
    "UserLoginSessionEvent",
    "UserLogoutSessionEvent",
    "UserPasswordChanged",
    "UserProfile",
    "UserSearchResult",
    "UserSession",
    "UserUnassignedFromGroup",
    "UserUpgradeEvent",
    "VAppCloneSpec",
    "VAppCloneSpecNetworkMappingPair",
    "VAppCloneSpecResourceMap",
    "VAppConfigInfo",
    "VAppConfigSpec",
    "VAppEntityConfigInfo",
    "VAppIPAssignmentInfo",
    "VAppOvfSectionInfo",
    "VAppOvfSectionSpec",
    "VAppProductInfo",
    "VAppProductSpec",
    "VAppPropertyInfo",
    "VAppPropertySpec",
    "VMFSDatastoreCreatedEvent",
    "VMFSDatastoreExpandedEvent",
    "VMFSDatastoreExtendedEvent",
    "VMotionLicenseExpiredEvent",
    "VMwareDVSConfigInfo",
    "VMwareDVSConfigSpec",
    "VMwareDVSFeatureCapability",
    "VMwareDVSPortSetting",
    "VMwareDVSPortgroupPolicy",
    "VMwareDVSPvlanConfigSpec",
    "VMwareDVSPvlanMapEntry",
    "VMwareDVSVspanConfigSpec",
    "VMwareIpfixConfig",
    "VMwareUplinkPortOrderPolicy",
    "VMwareVspanPort",
    "VMwareVspanSession",
    "VcAgentUninstallFailedEvent",
    "VcAgentUninstalledEvent",
    "VcAgentUpgradeFailedEvent",
    "VcAgentUpgradedEvent",
    "VimAccountPasswordChangedEvent",
    "VimCLIInfoExample",
    "VimCLIInfoInfo",
    "VimCLIInfoMethod",
    "VimCLIInfoParam",
    "VimEsxCLICLIFault",
    "VimEsxCLIesxclicommandlistEsxCliCommand",
    "VimEsxCLIfcoeadapterlistFcoeAdapterDevice",
    "VimEsxCLIfcoeniclistNicDevice",
    "VimEsxCLIhardwarebootdevicelistBootDeviceList",
    "VimEsxCLIhardwarecpucpuidgetCpuCpuId",
    "VimEsxCLIhardwarecpuglobalgetCpu",
    "VimEsxCLIhardwarecpulistCpu",
    "VimEsxCLIhardwarememorygetMemory",
    "VimEsxCLIhardwarepcilistPciDevice",
    "VimEsxCLIhardwareplatformgetPlatformGet",
    "VimEsxCLIiscsiadapterauthchapgetAdapterChapAuth",
    "VimEsxCLIiscsiadaptercapabilitiesgetAdapterCapabilities",
    "VimEsxCLIiscsiadapterdiscoverysendtargetauthchapgetSendtarget",
    "VimEsxCLIiscsiadapterdiscoverysendtargetlistSendtarget",
    "VimEsxCLIiscsiadapterdiscoverysendtargetparamgetiScsiParm",
    "VimEsxCLIiscsiadapterdiscoverystatictargetlistStatictarget",
    "VimEsxCLIiscsiadapterfirmwaregetAdapterFirmware",
    "VimEsxCLIiscsiadaptergetAdapterInfo",
    "VimEsxCLIiscsiadapterlistiScsiAdapter",
    "VimEsxCLIiscsiadapterparamgetiScsiParm",
    "VimEsxCLIiscsiadaptertargetlistTarget",
    "VimEsxCLIiscsiadaptertargetportalauthchapgetTargetAuth",
    "VimEsxCLIiscsiadaptertargetportallistTargetPortal",
    "VimEsxCLIiscsiadaptertargetportalparamgetiScsiParm",
    "VimEsxCLIiscsiibftbootgetIbftBoot",
    "VimEsxCLIiscsilogicalnetworkportallistLogicalNetworkPortal",
    "VimEsxCLIiscsinetworkportalipconfiggetNetworkPortal",
    "VimEsxCLIiscsinetworkportallistNetworkPortal",
    "VimEsxCLIiscsiphysicalnetworkportallistPhysicalNetworkPortal",
    "VimEsxCLIiscsiphysicalnetworkportalparamgetiScsiNetParm",
    "VimEsxCLIiscsipluginlistiScsiPlugin",
    "VimEsxCLIiscsisessionconnectionlistConnection",
    "VimEsxCLIiscsisessionlistSession",
    "VimEsxCLInetworkfencelistFenceSwitch",
    "VimEsxCLInetworkfencenetworkbtelistFenceBTE",
    "VimEsxCLInetworkfencenetworkbtelistFenceBteList",
    "VimEsxCLInetworkfencenetworklistFenceNetwork",
    "VimEsxCLInetworkfencenetworklistFenceNetworkList",
    "VimEsxCLInetworkfencenetworkportlistFencePort",
    "VimEsxCLInetworkfencenetworkportlistFencePortList",
    "VimEsxCLInetworkfirewallgetFirewall",
    "VimEsxCLInetworkfirewallrulesetallowediplistFirewallRulesetAllowedip",
    "VimEsxCLInetworkfirewallrulesetlistRuleset",
    "VimEsxCLInetworkfirewallrulesetrulelistFirewallPortRule",
    "VimEsxCLInetworkipconnectionlistIpConnection",
    "VimEsxCLInetworkipdnssearchlistDNSSearchList",
    "VimEsxCLInetworkipdnsserverlistNameServerList",
    "VimEsxCLInetworkipgetIPInfo",
    "VimEsxCLInetworkipinterfaceipv4getIPv4Interface",
    "VimEsxCLInetworkipinterfaceipv6addresslistIPv6Interface",
    "VimEsxCLInetworkipinterfaceipv6getIPv6Interface",
    "VimEsxCLInetworkipinterfacelistNetworkInterface",
    "VimEsxCLInetworkipneighborlistNetworkNeighbor",
    "VimEsxCLInetworknicgetNICDriverInfo",
    "VimEsxCLInetworknicgetNICInfo",
    "VimEsxCLInetworkniclistNic",
    "VimEsxCLInetworkvswitchdvsvmwarelistDVPort",
    "VimEsxCLInetworkvswitchdvsvmwarelistVDS",
    "VimEsxCLInetworkvswitchstandardlistVirtualSwitch",
    "VimEsxCLInetworkvswitchstandardpolicyfailovergetVirtualSwitchFailoverPolicy",
    "VimEsxCLInetworkvswitchstandardpolicysecuritygetVirtualSwitchSecurityPolicy",
    "VimEsxCLInetworkvswitchstandardpolicyshapinggetVirtualSwitchTrafficShapingPolicy",
    "VimEsxCLInetworkvswitchstandardportgrouplistPortGroup",
    "VimEsxCLInetworkvswitchstandardportgrouppolicyfailovergetPortGroupFailoverPolicy",
    "VimEsxCLInetworkvswitchstandardportgrouppolicysecuritygetPortGroupSecurityPolicy",
    "VimEsxCLInetworkvswitchstandardportgrouppolicyshapinggetPortGroupTrafficShapingPolicy",
    "VimEsxCLIsoftwareprofilegetImageProfile",
    "VimEsxCLIsoftwareprofileinstallInstallationResult",
    "VimEsxCLIsoftwareprofileupdateInstallationResult",
    "VimEsxCLIsoftwareprofilevalidateProfileValidationResult",
    "VimEsxCLIsoftwaresourcesprofilegetImageProfile",
    "VimEsxCLIsoftwaresourcesprofilelistImageProfileSummary",
    "VimEsxCLIsoftwaresourcesvibgetVIB",
    "VimEsxCLIsoftwaresourcesviblistVIBSummary",
    "VimEsxCLIsoftwarevibgetVIB",
    "VimEsxCLIsoftwarevibinstallInstallationResult",
    "VimEsxCLIsoftwareviblistVIBSummary",
    "VimEsxCLIsoftwarevibremoveInstallationResult",
    "VimEsxCLIsoftwarevibupdateInstallationResult",
    "VimEsxCLIstoragecoreadapterlistScsiAdapter",
    "VimEsxCLIstoragecoreadapterstatsgetScsiAdapterStats",
    "VimEsxCLIstoragecoreclaimruleconvertConvertedClaimRule",
    "VimEsxCLIstoragecoreclaimrulelistPSAClaimRule",
    "VimEsxCLIstoragecoredevicedetachedlistScsiDetachedDeviceListMap",
    "VimEsxCLIstoragecoredevicelistScsiDevice",
    "VimEsxCLIstoragecoredevicepartitionlistScsiDevicePartition",
    "VimEsxCLIstoragecoredevicestatsgetScsiDeviceStats",
    "VimEsxCLIstoragecoredevicevaaistatusgetScsiDevice",
    "VimEsxCLIstoragecoredeviceworldlistScsiDeviceWorld",
    "VimEsxCLIstoragecorepathlistScsiPath",
    "VimEsxCLIstoragecorepathstatsgetScsiPathStats",
    "VimEsxCLIstoragecorepluginlistPsaPlugin",
    "VimEsxCLIstoragecorepluginregistrationlistRegisteredModuleList",
    "VimEsxCLIstoragefilesystemlistFilesystemVolume",
    "VimEsxCLIstoragenfslistNasMount",
    "VimEsxCLIstoragenmpdevicelistNmpDevice",
    "VimEsxCLIstoragenmppathlistScsiPath",
    "VimEsxCLIstoragenmppspfixeddeviceconfiggetFixedDeviceConfiguration",
    "VimEsxCLIstoragenmppsplistPathSelectionPolicy",
    "VimEsxCLIstoragenmppsproundrobindeviceconfiggetRoundRobinDeviceConfiguration",
    "VimEsxCLIstoragenmpsatplistStorageArrayTypePlugin",
    "VimEsxCLIstoragenmpsatprulelistStorageArrayTypePluginRule",
    "VimEsxCLIstoragevmfsextentlistFilesystemVMFSExtents",
    "VimEsxCLIstoragevmfssnapshotextentlistVMFSSnapshotExtent",
    "VimEsxCLIstoragevmfssnapshotlistVMFSSnapshot",
    "VimEsxCLIsystembootdevicegetSystemBootDevice",
    "VimEsxCLIsystemcoredumpnetworkgetNetworkCoredump",
    "VimEsxCLIsystemcoredumppartitiongetKernelDumpParition",
    "VimEsxCLIsystemcoredumppartitionlistDumpPartition",
    "VimEsxCLIsystemhostnamegetFullyQualifiedHostName",
    "VimEsxCLIsystemmodulegetModuleDetails",
    "VimEsxCLIsystemmodulelistModule",
    "VimEsxCLIsystemmoduleparameterslistModuleParameter",
    "VimEsxCLIsystemprocesslistUserWorld",
    "VimEsxCLIsystemprocessstatsloadgetProcessStatsLoadGet",
    "VimEsxCLIsystemprocessstatsrunninggetProcessStatsRunningGet",
    "VimEsxCLIsystemsecpolicydomainlistDomainList",
    "VimEsxCLIsystemsettingsadvancedlistSettingsAdvancedOption",
    "VimEsxCLIsystemsettingskernellistSettingsKernel",
    "VimEsxCLIsystemsettingskeyboardlayoutlistLayout",
    "VimEsxCLIsystemsyslogconfiggetSyslogConfiguration",
    "VimEsxCLIsystemsyslogconfigloggerlistLoggerConfiguration",
    "VimEsxCLIsystemversiongetVersionGet",
    "VimEsxCLIsystemvisorfsgetVisorfsStatus",
    "VimEsxCLIsystemvisorfsramdisklistVisorfsRamdisk",
    "VimEsxCLIsystemvisorfstardisklistVisorfsTardisk",
    "VimEsxCLIvmprocesslistVirtualMachine",
    "VirtualAppImportSpec",
    "VirtualAppLinkInfo",
    "VirtualAppSummary",
    "VirtualBusLogicController",
    "VirtualBusLogicControllerOption",
    "VirtualCdrom",
    "VirtualCdromAtapiBackingInfo",
    "VirtualCdromAtapiBackingOption",
    "VirtualCdromIsoBackingInfo",
    "VirtualCdromIsoBackingOption",
    "VirtualCdromOption",
    "VirtualCdromPassthroughBackingInfo",
    "VirtualCdromPassthroughBackingOption",
    "VirtualCdromRemoteAtapiBackingInfo",
    "VirtualCdromRemoteAtapiBackingOption",
    "VirtualCdromRemotePassthroughBackingInfo",
    "VirtualCdromRemotePassthroughBackingOption",
    "VirtualController",
    "VirtualControllerOption",
    "VirtualDevice",
    "VirtualDeviceBackingInfo",
    "VirtualDeviceBackingOption",
    "VirtualDeviceConfigSpec",
    "VirtualDeviceConnectInfo",
    "VirtualDeviceConnectOption",
    "VirtualDeviceDeviceBackingInfo",
    "VirtualDeviceDeviceBackingOption",
    "VirtualDeviceFileBackingInfo",
    "VirtualDeviceFileBackingOption",
    "VirtualDeviceOption",
    "VirtualDevicePipeBackingInfo",
    "VirtualDevicePipeBackingOption",
    "VirtualDeviceRemoteDeviceBackingInfo",
    "VirtualDeviceRemoteDeviceBackingOption",
    "VirtualDeviceURIBackingInfo",
    "VirtualDeviceURIBackingOption",
    "VirtualDisk",
    "VirtualDiskAntiAffinityRuleSpec",
    "VirtualDiskFlatVer1BackingInfo",
    "VirtualDiskFlatVer1BackingOption",
    "VirtualDiskFlatVer2BackingInfo",
    "VirtualDiskFlatVer2BackingOption",
    "VirtualDiskId",
    "VirtualDiskOption",
    "VirtualDiskPartitionedRawDiskVer2BackingInfo",
    "VirtualDiskPartitionedRawDiskVer2BackingOption",
    "VirtualDiskRawDiskMappingVer1BackingInfo",
    "VirtualDiskRawDiskMappingVer1BackingOption",
    "VirtualDiskRawDiskVer2BackingInfo",
    "VirtualDiskRawDiskVer2BackingOption",
    "VirtualDiskSparseVer1BackingInfo",
    "VirtualDiskSparseVer1BackingOption",
    "VirtualDiskSparseVer2BackingInfo",
    "VirtualDiskSparseVer2BackingOption",
    "VirtualDiskSpec",
    "VirtualE1000",
    "VirtualE1000Option",
    "VirtualE1000e",
    "VirtualE1000eOption",
    "VirtualEnsoniq1371",
    "VirtualEnsoniq1371Option",
    "VirtualEthernetCard",
    "VirtualEthernetCardDVPortBackingOption",
    "VirtualEthernetCardDistributedVirtualPortBackingInfo",
    "VirtualEthernetCardLegacyNetworkBackingInfo",
    "VirtualEthernetCardLegacyNetworkBackingOption",
    "VirtualEthernetCardNetworkBackingInfo",
    "VirtualEthernetCardNetworkBackingOption",
    "VirtualEthernetCardOption",
    "VirtualFloppy",
    "VirtualFloppyDeviceBackingInfo",
    "VirtualFloppyDeviceBackingOption",
    "VirtualFloppyImageBackingInfo",
    "VirtualFloppyImageBackingOption",
    "VirtualFloppyOption",
    "VirtualFloppyRemoteDeviceBackingInfo",
    "VirtualFloppyRemoteDeviceBackingOption",
    "VirtualHardware",
    "VirtualHardwareOption",
    "VirtualHdAudioCard",
    "VirtualHdAudioCardOption",
    "VirtualIDEController",
    "VirtualIDEControllerOption",
    "VirtualKeyboard",
    "VirtualKeyboardOption",
    "VirtualLsiLogicController",
    "VirtualLsiLogicControllerOption",
    "VirtualLsiLogicSASController",
    "VirtualLsiLogicSASControllerOption",
    "VirtualMachineAffinityInfo",
    "VirtualMachineBootOptions",
    "VirtualMachineBootOptionsBootableCdromDevice",
    "VirtualMachineBootOptionsBootableDevice",
    "VirtualMachineBootOptionsBootableDiskDevice",
    "VirtualMachineBootOptionsBootableEthernetDevice",
    "VirtualMachineBootOptionsBootableFloppyDevice",
    "VirtualMachineCapability",
    "VirtualMachineCdromInfo",
    "VirtualMachineCloneSpec",
    "VirtualMachineConfigInfo",
    "VirtualMachineConfigInfoDatastoreUrlPair",
    "VirtualMachineConfigInfoOverheadInfo",
    "VirtualMachineConfigOption",
    "VirtualMachineConfigOptionDescriptor",
    "VirtualMachineConfigSpec",
    "VirtualMachineConfigSummary",
    "VirtualMachineConsolePreferences",
    "VirtualMachineCpuIdInfoSpec",
    "VirtualMachineDatastoreInfo",
    "VirtualMachineDatastoreVolumeOption",
    "VirtualMachineDefaultPowerOpInfo",
    "VirtualMachineDeviceRuntimeInfo",
    "VirtualMachineDeviceRuntimeInfoDeviceRuntimeState",
    "VirtualMachineDeviceRuntimeInfoVirtualEthernetCardRuntimeState",
    "VirtualMachineDiskDeviceInfo",
    "VirtualMachineDisplayTopology",
    "VirtualMachineFileInfo",
    "VirtualMachineFileLayout",
    "VirtualMachineFileLayoutDiskLayout",
    "VirtualMachineFileLayoutEx",
    "VirtualMachineFileLayoutExDiskLayout",
    "VirtualMachineFileLayoutExDiskUnit",
    "VirtualMachineFileLayoutExFileInfo",
    "VirtualMachineFileLayoutExSnapshotLayout",
    "VirtualMachineFileLayoutSnapshotLayout",
    "VirtualMachineFlagInfo",
    "VirtualMachineFloppyInfo",
    "VirtualMachineGuestSummary",
    "VirtualMachineIdeDiskDeviceInfo",
    "VirtualMachineIdeDiskDevicePartitionInfo",
    "VirtualMachineImportSpec",
    "VirtualMachineLegacyNetworkSwitchInfo",
    "VirtualMachineMemoryReservationInfo",
    "VirtualMachineMemoryReservationSpec",
    "VirtualMachineMessage",
    "VirtualMachineMksTicket",
    "VirtualMachineNetworkInfo",
    "VirtualMachineNetworkShaperInfo",
    "VirtualMachineParallelInfo",
    "VirtualMachinePciPassthroughInfo",
    "VirtualMachineQuestionInfo",
    "VirtualMachineQuickStats",
    "VirtualMachineRelocateSpec",
    "VirtualMachineRelocateSpecDiskLocator",
    "VirtualMachineRuntimeInfo",
    "VirtualMachineRuntimeInfoDasProtectionState",
    "VirtualMachineScsiDiskDeviceInfo",
    "VirtualMachineScsiPassthroughInfo",
    "VirtualMachineSerialInfo",
    "VirtualMachineSnapshotInfo",
    "VirtualMachineSnapshotTree",
    "VirtualMachineSoundInfo",
    "VirtualMachineStorageInfo",
    "VirtualMachineStorageSummary",
    "VirtualMachineSummary",
    "VirtualMachineTargetInfo",
    "VirtualMachineTicket",
    "VirtualMachineUsageOnDatastore",
    "VirtualMachineUsbInfo",
    "VirtualMachineVMCIDevice",
    "VirtualMachineVMCIDeviceOption",
    "VirtualMachineVMIROM",
    "VirtualMachineVideoCard",
    "VirtualNicManagerNetConfig",
    "VirtualPCIController",
    "VirtualPCIControllerOption",
    "VirtualPCIPassthrough",
    "VirtualPCIPassthroughDeviceBackingInfo",
    "VirtualPCIPassthroughDeviceBackingOption",
    "VirtualPCIPassthroughOption",
    "VirtualPCNet32",
    "VirtualPCNet32Option",
    "VirtualPS2Controller",
    "VirtualPS2ControllerOption",
    "VirtualParallelPort",
    "VirtualParallelPortDeviceBackingInfo",
    "VirtualParallelPortDeviceBackingOption",
    "VirtualParallelPortFileBackingInfo",
    "VirtualParallelPortFileBackingOption",
    "VirtualParallelPortOption",
    "VirtualPointingDevice",
    "VirtualPointingDeviceBackingOption",
    "VirtualPointingDeviceDeviceBackingInfo",
    "VirtualPointingDeviceOption",
    "VirtualSCSIController",
    "VirtualSCSIControllerOption",
    "VirtualSCSIPassthrough",
    "VirtualSCSIPassthroughDeviceBackingInfo",
    "VirtualSCSIPassthroughDeviceBackingOption",
    "VirtualSCSIPassthroughOption",
    "VirtualSIOController",
    "VirtualSIOControllerOption",
    "VirtualSerialPort",
    "VirtualSerialPortDeviceBackingInfo",
    "VirtualSerialPortDeviceBackingOption",
    "VirtualSerialPortFileBackingInfo",
    "VirtualSerialPortFileBackingOption",
    "VirtualSerialPortOption",
    "VirtualSerialPortPipeBackingInfo",
    "VirtualSerialPortPipeBackingOption",
    "VirtualSerialPortURIBackingInfo",
    "VirtualSerialPortURIBackingOption",
    "VirtualSoundBlaster16",
    "VirtualSoundBlaster16Option",
    "VirtualSoundCard",
    "VirtualSoundCardDeviceBackingInfo",
    "VirtualSoundCardDeviceBackingOption",
    "VirtualSoundCardOption",
    "VirtualSwitchProfile",
    "VirtualSwitchSelectionProfile",
    "VirtualUSB",
    "VirtualUSBController",
    "VirtualUSBControllerOption",
    "VirtualUSBOption",
    "VirtualUSBRemoteClientBackingInfo",
    "VirtualUSBRemoteClientBackingOption",
    "VirtualUSBRemoteHostBackingInfo",
    "VirtualUSBRemoteHostBackingOption",
    "VirtualUSBUSBBackingInfo",
    "VirtualUSBUSBBackingOption",
    "VirtualUSBXHCIController",
    "VirtualUSBXHCIControllerOption",
    "VirtualVMIROMOption",
    "VirtualVideoCardOption",
    "VirtualVmxnet",
    "VirtualVmxnet2",
    "VirtualVmxnet2Option",
    "VirtualVmxnet3",
    "VirtualVmxnet3Option",
    "VirtualVmxnetOption",
    "VlanProfile",
    "VmAcquiredMksTicketEvent",
    "VmAcquiredTicketEvent",
    "VmAutoRenameEvent",
    "VmBeingClonedEvent",
    "VmBeingClonedNoFolderEvent",
    "VmBeingCreatedEvent",
    "VmBeingDeployedEvent",
    "VmBeingHotMigratedEvent",
    "VmBeingMigratedEvent",
    "VmBeingRelocatedEvent",
    "VmCloneEvent",
    "VmCloneFailedEvent",
    "VmClonedEvent",
    "VmConfigFileInfo",
    "VmConfigFileQuery",
    "VmConfigFileQueryFilter",
    "VmConfigFileQueryFlags",
    "VmConfigInfo",
    "VmConfigMissingEvent",
    "VmConfigSpec",
    "VmConnectedEvent",
    "VmCreatedEvent",
    "VmDasBeingResetEvent",
    "VmDasBeingResetWithScreenshotEvent",
    "VmDasResetFailedEvent",
    "VmDasUpdateErrorEvent",
    "VmDasUpdateOkEvent",
    "VmDateRolledBackEvent",
    "VmDeployFailedEvent",
    "VmDeployedEvent",
    "VmDisconnectedEvent",
    "VmDiscoveredEvent",
    "VmDiskFailedEvent",
    "VmDiskFileInfo",
    "VmDiskFileQuery",
    "VmDiskFileQueryFilter",
    "VmDiskFileQueryFlags",
    "VmEmigratingEvent",
    "VmEndRecordingEvent",
    "VmEndReplayingEvent",
    "VmEvent",
    "VmEventArgument",
    "VmFailedMigrateEvent",
    "VmFailedRelayoutEvent",
    "VmFailedRelayoutOnVmfs2DatastoreEvent",
    "VmFailedStartingSecondaryEvent",
    "VmFailedToPowerOffEvent",
    "VmFailedToPowerOnEvent",
    "VmFailedToRebootGuestEvent",
    "VmFailedToResetEvent",
    "VmFailedToShutdownGuestEvent",
    "VmFailedToStandbyGuestEvent",
    "VmFailedToSuspendEvent",
    "VmFailedUpdatingSecondaryConfig",
    "VmFailoverFailed",
    "VmFaultToleranceStateChangedEvent",
    "VmFaultToleranceTurnedOffEvent",
    "VmFaultToleranceVmTerminatedEvent",
    "VmGuestRebootEvent",
    "VmGuestShutdownEvent",
    "VmGuestStandbyEvent",
    "VmHealthMonitoringStateChangedEvent",
    "VmInstanceUuidAssignedEvent",
    "VmInstanceUuidChangedEvent",
    "VmInstanceUuidConflictEvent",
    "VmLogFileInfo",
    "VmLogFileQuery",
    "VmMacAssignedEvent",
    "VmMacChangedEvent",
    "VmMacConflictEvent",
    "VmMaxFTRestartCountReached",
    "VmMaxRestartCountReached",
    "VmMessageErrorEvent",
    "VmMessageEvent",
    "VmMessageWarningEvent",
    "VmMigratedEvent",
    "VmNoCompatibleHostForSecondaryEvent",
    "VmNoNetworkAccessEvent",
    "VmNvramFileInfo",
    "VmNvramFileQuery",
    "VmOrphanedEvent",
    "VmPodConfigForPlacement",
    "VmPortGroupProfile",
    "VmPowerOffOnIsolationEvent",
    "VmPoweredOffEvent",
    "VmPoweredOnEvent",
    "VmPoweringOnWithCustomizedDVPortEvent",
    "VmPrimaryFailoverEvent",
    "VmReconfiguredEvent",
    "VmRegisteredEvent",
    "VmRelayoutSuccessfulEvent",
    "VmRelayoutUpToDateEvent",
    "VmReloadFromPathEvent",
    "VmReloadFromPathFailedEvent",
    "VmRelocateFailedEvent",
    "VmRelocateSpecEvent",
    "VmRelocatedEvent",
    "VmRemoteConsoleConnectedEvent",
    "VmRemoteConsoleDisconnectedEvent",
    "VmRemovedEvent",
    "VmRenamedEvent",
    "VmResettingEvent",
    "VmResourcePoolMovedEvent",
    "VmResourceReallocatedEvent",
    "VmRestartedOnAlternateHostEvent",
    "VmResumingEvent",
    "VmSecondaryAddedEvent",
    "VmSecondaryDisabledBySystemEvent",
    "VmSecondaryDisabledEvent",
    "VmSecondaryEnabledEvent",
    "VmSecondaryStartedEvent",
    "VmShutdownOnIsolationEvent",
    "VmSnapshotFileInfo",
    "VmSnapshotFileQuery",
    "VmStartRecordingEvent",
    "VmStartReplayingEvent",
    "VmStartingEvent",
    "VmStartingSecondaryEvent",
    "VmStaticMacConflictEvent",
    "VmStoppingEvent",
    "VmSuspendedEvent",
    "VmSuspendingEvent",
    "VmTimedoutStartingSecondaryEvent",
    "VmUnsupportedStartingEvent",
    "VmUpgradeCompleteEvent",
    "VmUpgradeFailedEvent",
    "VmUpgradingEvent",
    "VmUuidAssignedEvent",
    "VmUuidChangedEvent",
    "VmUuidConflictEvent",
    "VmWwnAssignedEvent",
    "VmWwnChangedEvent",
    "VmWwnConflictEvent",
    "VmfsDatastoreAllExtentOption",
    "VmfsDatastoreBaseOption",
    "VmfsDatastoreCreateSpec",
    "VmfsDatastoreExpandSpec",
    "VmfsDatastoreExtendSpec",
    "VmfsDatastoreInfo",
    "VmfsDatastoreMultipleExtentOption",
    "VmfsDatastoreOption",
    "VmfsDatastoreSingleExtentOption",
    "VmfsDatastoreSpec",
    "VmwareDistributedVirtualSwitchPvlanSpec",
    "VmwareDistributedVirtualSwitchTrunkVlanSpec",
    "VmwareDistributedVirtualSwitchVlanIdSpec",
    "VmwareDistributedVirtualSwitchVlanSpec",
    "VmwareUplinkPortTeamingPolicy",
    "VnicPortArgument",
    "WaitOptions",
    "WarningUpgradeEvent",
    "WeeklyTaskScheduler",
    "WinNetBIOSConfigInfo",
    "DbConnectionSpec",
    "Edge",
    "EntityReference",
    "FilterSpec",
    "FilterSpecConstraint",
    "Map",
    "Metadata",
    "Node",
    "NodeProperty",
    "QueryResult",
    "QuerySpec",
    "RowData",
    "SmsProviderInfo",
    "SmsTaskInfo",
    "SortSpec",
    "SmsProviderSpec",
    "VasaProviderSpec"
    ])




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class HardwarePci(Base):
    '''
    PCI device information and configuration.
    '''
    moid = 'ha-cli-handler-hardware-pci'
    def list(self):
        '''
        List all of the PCI devices on this host.
        :returns: vim.EsxCLI.hardware.pci.list.PciDevice[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.hardware.pci.List',
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def FilesystemQuiesceFault(vim, *args, **kwargs):
    '''This fault is thrown when creating a quiesced snapshot failed because the
    create snapshot operation exceeded the time limit for holding off I/O in the
    frozen VM.This indicates that when we attempted to thaw the VM after creating
    the snapshot, we got an error back indicating that the VM was not frozen
    anymore. In this case, we roll back the entire snapshot create operation and
    throw this exception.'''

    obj = vim.client.factory.create('{urn:vim25}FilesystemQuiesceFault')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'dynamicProperty', 'dynamicType', 'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj
